==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
export let WebSliderLabelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderLabelDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderLabelDescriptionMetadata.a == null) {
                WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
            }
            if (a.j(WebSliderLabelDescriptionMetadata.a)) {
                return;
            }
            a.y(WebSliderLabelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SliderLabel");
            a.item("__tagNameWC", "String:igc-slider-label");
        }
        static d(a) {
            WebSliderLabelDescriptionMetadata.b(a);
            a.aa("WebSliderLabel", () => new WebSliderLabelDescription());
            a.z("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
        }
    }
    WebSliderLabelDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebSliderLabelDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSliderLabelDescription } from "./WebSliderLabelDescription";
/**
 * @hidden
 */
export let WebSliderLabelDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSliderLabelDescriptionMetadata extends Base {
        static b(a) {
            if (WebSliderLabelDescriptionMetadata.a == null) {
                WebSliderLabelDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSliderLabelDescriptionMetadata.c(WebSliderLabelDescriptionMetadata.a);
            }
            if (a.k(WebSliderLabelDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebSliderLabelDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:SliderLabel");
            a.item("__tagNameWC", "String:igc-slider-label");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSliderLabelDescriptionMetadata.b(a);
            a.ac("WebSliderLabel", () => new WebSliderLabelDescription());
            a.ab("WebSliderLabel", WebSliderLabelDescriptionMetadata.a);
        }
    }
    WebSliderLabelDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSliderLabelDescriptionMetadata, 'WebSliderLabelDescriptionMetadata');
    WebSliderLabelDescriptionMetadata.a = null;
    return WebSliderLabelDescriptionMetadata;
})();
